@@ -1,7 +1,7 @@
 import argparse
-from detect_contamination import detect_contamination
-from table import table
-from graph import draw
+from detect_contamination.detect_contamination import detect_contamination
+from detect_contamination.table import table
+from detect_contamination.graph import draw
 
 def detection(args: argparse.Namespace):
     results = detect_contamination(args)
